@@ -1,12 +1,13 @@
 SELECT 
   e.aggregate_id,
   n.name,
-  e.payload,
+  e.json::TEXT,
+  e.bytes,
   e.time,
-  e.sequence
+  e.id
 FROM event e
-LEFT JOIN event_name n
-  ON e.name_id = n.id
+LEFT JOIN event_meta n
+  ON e.meta_id = n.id
 WHERE
   e.aggregate_type_id = $1 AND
   e.aggregate_id = $2
