@@ -1,7 +1,7 @@
 SELECT 
   n.id,
   n.name
-FROM event_name n
+FROM event_meta n
 WHERE n.aggregate_type_id = $1
 -- get most recently created
 ORDER BY n.id DESC
