@@ -5,8 +5,8 @@ pub enum Error {
     #[error("invalid data: {0}")]
     InvalidData(String),
 
-    #[error("store failed to encode/decode events in json: ${0}")]
-    SerdeJson(#[from] serde_json::Error),
+    #[error("unable to parse event: ${0}")]
+    PersistedError(#[from] timesource_core::PersistedError),
 
     #[error("store's sqlx client returned an error: ${0}")]
     Sqlx(#[from] sqlx::Error),
