@@ -1,8 +1,8 @@
 pub mod aggregate;
+pub mod consumer;
 pub mod error;
 pub mod repository;
 pub mod store;
-pub mod subscription;
 
 #[macro_use]
 extern crate async_trait;
@@ -15,7 +15,9 @@ extern crate timesource_derive;
 use timesource_core::event;
 
 pub use aggregate::{Aggregate, AggregateRoot};
-pub use event::{Persisted, TimescaleEventPayload};
+pub use event::{
+    EventPayloadEncoding, PayloadEncoding, Persisted, PersistedError, TimesourceEventPayload,
+};
 
 #[doc(hidden)]
 pub use timesource_derive::*;
